import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 案例服务对象基类
 *
 * @export
 * @class IncidentServiceBase
 * @extends {EntityServie}
 */
export default class IncidentServiceBase extends EntityService {

    /**
     * Creates an instance of  IncidentServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  IncidentServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof IncidentServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='incident';
        this.APPDEKEY = 'incidentid';
        this.APPDENAME = 'incidents';
        this.APPDETEXT = 'title';
        this.APPNAME = 'crm';
        this.SYSTEMNAME = 'ibizbusinesscentral';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/incidents/${context.incident}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let incidentsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_incidents'),'undefined')){
            incidentsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_incidents') as any);
            if(incidentsData && incidentsData.length && incidentsData.length > 0){
                incidentsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.incidentid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.incidents = incidentsData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/incidents`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_incidents',JSON.stringify(res.data.incidents));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let incidentsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_incidents'),'undefined')){
            incidentsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_incidents') as any);
            if(incidentsData && incidentsData.length && incidentsData.length > 0){
                incidentsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.incidentid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.incidents = incidentsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/incidents/${context.incident}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_incidents',JSON.stringify(res.data.incidents));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/incidents/${context.incident}`,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/incidents/${context.incident}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_incidents',JSON.stringify(res.data.incidents));
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/incidents/getdraft`,isloading);
        res.data.incident = data.incident;
            this.tempStorage.setItem(context.srfsessionkey+'_incidents',JSON.stringify(res.data.incidents));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/incidents/${context.incident}/checkkey`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let incidentsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_incidents'),'undefined')){
            incidentsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_incidents') as any);
            if(incidentsData && incidentsData.length && incidentsData.length > 0){
                incidentsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.incidentid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.incidents = incidentsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/incidents/${context.incident}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_incidents',JSON.stringify(res.data.incidents));
            return res;
    }

    /**
     * FetchByParentKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async FetchByParentKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/incidents/fetchbyparentkey`,tempData,isloading);
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IncidentServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/incidents/fetchdefault`,tempData,isloading);
    }
}